"""
    picasso.avgroi
    ~~~~~~~~~~~~~~~~

    Return average intensity of Spot

    :author: Maximilian Thomas Strauss, 2016
    :copyright: Copyright (c) 2016 Jungmann Lab, MPI of Biochemistry
"""

from scipy import optimize as _optimize
import numpy as _np
from tqdm import tqdm as _tqdm
import numba as _numba
import multiprocessing as _multiprocessing
from concurrent import futures as _futures
from . import postprocess as _postprocess


@_numba.jit(nopython=True, nogil=True)
def _sum(spot, size):
    _sum_ = 0.0
    for i in range(size):
        for j in range(size):
            _sum_ += spot[i, j]

    return _sum_


def fit_spot(spot):
    size = spot.shape[0]
    avg_roi = _sum(spot, size)
    # result is [x, y, photons, bg, sx, sy]
    result = [0, 0, avg_roi, avg_roi, 1, 1]
    return result


def fit_spots(spots):
    theta = _np.empty((len(spots), 6), dtype=_np.float32)
    theta.fill(_np.nan)
    for i, spot in enumerate(spots):
        theta[i] = fit_spot(spot)
    return theta


def fit_spots_parallel(spots, asynch=False):
    n_workers = max(1, int(0.75 * _multiprocessing.cpu_count()))
    n_spots = len(spots)
    n_tasks = 100 * n_workers
    spots_per_task = [
        int(n_spots / n_tasks + 1)
        if _ < n_spots % n_tasks
        else int(n_spots / n_tasks)
        for _ in range(n_tasks)
    ]
    start_indices = _np.cumsum([0] + spots_per_task[:-1])
    fs = []
    executor = _futures.ProcessPoolExecutor(n_workers)
    for i, n_spots_task in zip(start_indices, spots_per_task):
        fs.append(executor.submit(fit_spots, spots[i: i + n_spots_task]))
    if asynch:
        return fs
    with _tqdm(total=n_tasks, unit="task") as progress_bar:
        for f in _futures.as_completed(fs):
            progress_bar.update()
    return fits_from_futures(fs)


def fits_from_futures(futures):
    theta = [_.result() for _ in futures]
    return _np.vstack(theta)


def locs_from_fits(identifications, theta, box, em):
    # box_offset = int(box/2)
    x = theta[:, 0] + identifications.x  # - box_offset
    y = theta[:, 1] + identifications.y  # - box_offset
    lpx = _postprocess.localization_precision(
        theta[:, 2], theta[:, 4], theta[:, 3], em=em
    )
    lpy = _postprocess.localization_precision(
        theta[:, 2], theta[:, 5], theta[:, 3], em=em
    )
    a = _np.maximum(theta[:, 4], theta[:, 5])
    b = _np.minimum(theta[:, 4], theta[:, 5])
    ellipticity = (a - b) / a
    if hasattr(identifications, "n_id"):
        locs = _np.rec.array(
            (
                identifications.frame,
                x,
                y,
                theta[:, 2],
                theta[:, 4],
                theta[:, 5],
                theta[:, 3],
                lpx,
                lpy,
                ellipticity,
                identifications.net_gradient,
                identifications.n_id,
            ),
            dtype=[
                ("frame", "u4"),
                ("x", "f4"),
                ("y", "f4"),
                ("photons", "f4"),
                ("sx", "f4"),
                ("sy", "f4"),
                ("bg", "f4"),
                ("lpx", "f4"),
                ("lpy", "f4"),
                ("ellipticity", "f4"),
                ("net_gradient", "f4"),
                ("n_id", "u4"),
            ],
        )
        locs.sort(kind="mergesort", order="n_id")
    else:
        locs = _np.rec.array(
            (
                identifications.frame,
                x,
                y,
                theta[:, 2],
                theta[:, 4],
                theta[:, 5],
                theta[:, 3],
                lpx,
                lpy,
                ellipticity,
                identifications.net_gradient,
            ),
            dtype=[
                ("frame", "u4"),
                ("x", "f4"),
                ("y", "f4"),
                ("photons", "f4"),
                ("sx", "f4"),
                ("sy", "f4"),
                ("bg", "f4"),
                ("lpx", "f4"),
                ("lpy", "f4"),
                ("ellipticity", "f4"),
                ("net_gradient", "f4"),
            ],
        )
        locs.sort(kind="mergesort", order="frame")
    return locs



base_sequences = [['Position', 'Name', 'Sequence'],
 ['A1', '21[32]23[31]BLK', 'TTTTCACTCAAAGGGCGAAAAACCATCACC'],
 ['B1', '23[32]22[48]BLK', 'CAAATCAAGTTTTTTGGGGTCGAAACGTGGA'],
 ['C1', '21[56]23[63]BLK', 'AGCTGATTGCCCTTCAGAGTCCACTATTAAAGGGTGCCGT'],
 ['D1', '23[64]22[80]BLK', 'AAAGCACTAAATCGGAACCCTAATCCAGTT'],
 ['E1', '21[96]23[95]BLK', 'AGCAAGCGTAGGGTTGAGTGTTGTAGGGAGCC'],
 ['F1', '23[96]22[112]BLK', 'CCCGATTTAGAGCTTGACGGGGAAAAAGAATA'],
 ['G1', '21[120]23[127]BLK', 'CCCAGCAGGCGAAAAATCCCTTATAAATCAAGCCGGCG'],
 ['H1', '21[160]22[144]BLK', 'TCAATATCGAACCTCAAATATCAATTCCGAAA'],
 ['I1', '23[128]23[159]BLK', 'AACGTGGCGAGAAAGGAAGGGAAACCAGTAA'],
 ['J1', '23[160]22[176]BLK', 'TAAAAGGGACATTCTGGCCAACAAAGCATC'],
 ['K1', '21[184]23[191]BLK', 'TCAACAGTTGAAAGGAGCAAATGAAAAATCTAGAGATAGA'],
 ['L1', '23[192]22[208]BLK', 'ACCCTTCTGACCTGAAAGCGTAAGACGCTGAG'],
 ['M1', '21[224]23[223]BLK', 'CTTTAGGGCCTGCAACAGTGCCAATACGTG'],
 ['N1', '23[224]22[240]BLK', 'GCACAGACAATATTTTTGAATGGGGTCAGTA'],
 ['O1', '21[248]23[255]BLK', 'AGATTAGAGCCGTCAAAAAACAGAGGTGAGGCCTATTAGT'],
 ['P1', '23[256]22[272]BLK', 'CTTTAATGCGCGAACTGATAGCCCCACCAG'],
 ['A2', '19[32]21[31]BLK', 'GTCGACTTCGGCCAACGCGCGGGGTTTTTC'],
 ['B2', '22[47]20[48]BLK', 'CTCCAACGCAGTGAGACGGGCAACCAGCTGCA'],
 ['D2', '22[79]20[80]BLK', 'TGGAACAACCGCCTGGCCCTGAGGCCCGCT'],
 ['E2', '19[96]21[95]BLK', 'CTGTGTGATTGCGTTGCGCTCACTAGAGTTGC'],
 ['F2', '22[111]20[112]BLK', 'GCCCGAGAGTCCACGCTGGTTTGCAGCTAACT'],
 ['H2', '19[160]20[144]BLK', 'GCAATTCACATATTCCTGATTATCAAAGTGTA'],
 ['I2', '22[143]21[159]BLK', 'TCGGCAAATCCTGTTTGATGGTGGACCCTCAA'],
 ['J2', '22[175]20[176]BLK', 'ACCTTGCTTGGTCAGTTGGCAAAGAGCGGA'],
 ['L2', '22[207]20[208]BLK', 'AGCCAGCAATTGAGGAAGGTTATCATCATTTT'],
 ['M2', '19[224]21[223]BLK', 'CTACCATAGTTTGAGTAACATTTAAAATAT'],
 ['N2', '22[239]20[240]BLK', 'TTAACACCAGCACTAACAACTAATCGTTATTA'],
 ['P2', '22[271]20[272]BLK', 'CAGAAGATTAGATAATACATTTGTCGACAA'],
 ['A3', '17[32]19[31]BLK', 'TGCATCTTTCCCAGTCACGACGGCCTGCAG'],
 ['B3', '20[47]18[48]BLK', 'TTAATGAACTAGAGGATCCCCGGGGGGTAACG'],
 ['D3', '20[79]18[80]BLK', 'TTCCAGTCGTAATCATGGTCATAAAAGGGG'],
 ['E3', '17[96]19[95]BLK', 'GCTTTCCGATTACGCCAGCTGGCGGCTGTTTC'],
 ['F3', '20[111]18[112]BLK', 'CACATTAAAATTGTTATCCGCTCATGCGGGCC'],
 ['H3', '17[160]18[144]BLK', 'AGAAAACAAAGAAGATGATGAAACAGGCTGCG'],
 ['I3', '20[143]19[159]BLK', 'AAGCCTGGTACGAGCCGGAAGCATAGATGATG'],
 ['J3', '20[175]18[176]BLK', 'ATTATCATTCAATATAATCCTGACAATTAC'],
 ['L3', '20[207]18[208]BLK', 'GCGGAACATCTGAATAATGGAAGGTACAAAAT'],
 ['M3', '17[224]19[223]BLK', 'CATAAATCTTTGAATACCAAGTGTTAGAAC'],
 ['N3', '20[239]18[240]BLK', 'ATTTTAAAATCAAAATTATTTGCACGGATTCG'],
 ['P3', '20[271]18[272]BLK', 'CTCGTATTAGAAATTGCGTAGATACAGTAC'],
 ['A4', '15[32]17[31]BLK', 'TAATCAGCGGATTGACCGTAATCGTAACCG'],
 ['B4', '18[47]16[48]BLK', 'CCAGGGTTGCCAGTTTGAGGGGACCCGTGGGA'],
 ['C4', '15[64]18[64]BLK', 'GTATAAGCCAACCCGTCGGATTCTGACGACAGTATCGGCCGCAAGGCG'],
 ['D4', '18[79]16[80]BLK', 'GATGTGCTTCAGGAAGATCGCACAATGTGA'],
 ['E4', '15[96]17[95]BLK', 'ATATTTTGGCTTTCATCAACATTATCCAGCCA'],
 ['F4', '18[111]16[112]BLK', 'TCTTCGCTGCACCGCTTCTGGTGCGGCCTTCC'],
 ['G4', '15[128]18[128]BLK', 'TAAATCAAAATAATTCGCGTCTCGGAAACCAGGCAAAGGGAAGG'],
 ['H4', '15[160]16[144]BLK', 'ATCGCAAGTATGTAAATGCTGATGATAGGAAC'],
 ['I4', '18[143]17[159]BLK', 'CAACTGTTGCGCCATTCGCCATTCAAACATCA'],
 ['J4', '18[175]16[176]BLK', 'CTGAGCAAAAATTAATTACATTTTGGGTTA'],
 ['K4', '15[192]18[192]BLK', 'TCAAATATAACCTCCGGCTTAGGTAACAATTTCATTTGAAGGCGAATT'],
 ['L4', '18[207]16[208]BLK', 'CGCGCAGATTACCTTTTTTAATGGGAGAGACT'],
 ['M4', '15[224]17[223]BLK', 'CCTAAATCAAAATCATAGGTCTAAACAGTA'],
 ['N4', '18[239]16[240]BLK', 'CCTGATTGCAATATATGTGAGTGATCAATAGT'],
 ['O4', '15[256]18[256]BLK', 'GTGATAAAAAGACGCTGAGAAGAGATAACCTTGCTTCTGTTCGGGAGA'],
 ['P4', '18[271]16[272]BLK', 'CTTTTACAAAATCGTCGCTATTAGCGATAG'],
 ['A5', '13[32]15[31]BLK', 'AACGCAAAATCGATGAACGGTACCGGTTGA'],
 ['B5', '16[47]14[48]BLK', 'ACAAACGGAAAAGCCCCAAAAACACTGGAGCA'],
 ['C5', '13[64]15[63]BLK', 'TATATTTTGTCATTGCCTGAGAGTGGAAGATT'],
 ['D5', '16[79]14[80]BLK', 'GCGAGTAAAAATATTTAAATTGTTACAAAG'],
 ['E5', '13[96]15[95]BLK', 'TAGGTAAACTATTTTTGAGAGATCAAACGTTA'],
 ['F5', '16[111]14[112]BLK', 'TGTAGCCATTAAAATTCGCATTAAATGCCGGA'],
 ['G5', '13[128]15[127]BLK', 'GAGACAGCTAGCTGATAAATTAATTTTTGT'],
 ['H5', '13[160]14[144]BLK', 'GTAATAAGTTAGGCAGAGGCATTTATGATATT'],
 ['I5', '16[143]15[159]BLK', 'GCCATCAAGCTCATTTTTTAACCACAAATCCA'],
 ['J5', '16[175]14[176]BLK', 'TATAACTAACAAAGAACGCGAGAACGCCAA'],
 ['K5', '13[192]15[191]BLK', 'GTAAAGTAATCGCCATATTTAACAAAACTTTT'],
 ['L5', '16[207]14[208]BLK', 'ACCTTTTTATTTTAGTTAATTTCATAGGGCTT'],
 ['M5', '13[224]15[223]BLK', 'ACAACATGCCAACGCTCAACAGTCTTCTGA'],
 ['N5', '16[239]14[240]BLK', 'GAATTTATTTAATGGTTTGAAATATTCTTACC'],
 ['O5', '13[256]15[255]BLK', 'GTTTATCAATATGCGTTATACAAACCGACCGT'],
 ['P5', '16[271]14[272]BLK', 'CTTAGATTTAAGGCGTTAAATAAAGCCTGT'],
 ['A6', '11[32]13[31]BLK', 'AACAGTTTTGTACCAAAAACATTTTATTTC'],
 ['B6', '14[47]12[48]BLK', 'AACAAGAGGGATAAAAATTTTTAGCATAAAGC'],
 ['C6', '11[64]13[63]BLK', 'GATTTAGTCAATAAAGCCTCAGAGAACCCTCA'],
 ['D6', '14[79]12[80]BLK', 'GCTATCAGAAATGCAATGCCTGAATTAGCA'],
 ['E6', '11[96]13[95]BLK', 'AATGGTCAACAGGCAAGGCAAAGAGTAATGTG'],
 ['F6', '14[111]12[112]BLK', 'GAGGGTAGGATTCAAAAGGGTGAGACATCCAA'],
 ['G6', '11[128]13[127]BLK', 'TTTGGGGATAGTAGTAGCATTAAAAGGCCG'],
 ['H6', '11[160]12[144]BLK', 'CCAATAGCTCATCGTAGGAATCATGGCATCAA'],
 ['I6', '14[143]13[159]BLK', 'CAACCGTTTCAAATCACCATCAATTCGAGCCA'],
 ['J6', '14[175]12[176]BLK', 'CATGTAATAGAATATAAAGTACCAAGCCGT'],
 ['K6', '11[192]13[191]BLK', 'TATCCGGTCTCATCGAGAACAAGCGACAAAAG'],
 ['L6', '14[207]12[208]BLK', 'AATTGAGAATTCTGTCCAGACGACTAAACCAA'],
 ['M6', '11[224]13[223]BLK', 'GCGAACCTCCAAGAACGGGTATGACAATAA'],
 ['N6', '14[239]12[240]BLK', 'AGTATAAAGTTCAGCTAATGCAGATGTCTTTC'],
 ['O6', '11[256]13[255]BLK', 'GCCTTAAACCAATCAATAATCGGCACGCGCCT'],
 ['P6', '14[271]12[272]BLK', 'TTAGTATCACAATAGATAAGTCCACGAGCA'],
 ['A7', '9[32]11[31]BLK', 'TTTACCCCAACATGTTTTAAATTTCCATAT'],
 ['B7', '12[47]10[48]BLK', 'TAAATCGGGATTCCCAATTCTGCGATATAATG'],
 ['C7', '9[64]11[63]BLK', 'CGGATTGCAGAGCTTAATTGCTGAAACGAGTA'],
 ['D7', '12[79]10[80]BLK', 'AAATTAAGTTGACCATTAGATACTTTTGCG'],
 ['E7', '9[96]11[95]BLK', 'CGAAAGACTTTGATAAGAGGTCATATTTCGCA'],
 ['F7', '12[111]10[112]BLK', 'TAAATCATATAACCTGTTTAGCTAACCTTTAA'],
 ['G7', '9[128]11[127]BLK', 'GCTTCAATCAGGATTAGAGAGTTATTTTCA'],
 ['H7', '9[160]10[144]BLK', 'AGAGAGAAAAAAATGAAAATAGCAAGCAAACT'],
 ['I7', '12[143]11[159]BLK', 'TTCTACTACGCGAGCTGAAAAGGTTACCGCGC'],
 ['J7', '12[175]10[176]BLK', 'TTTTATTTAAGCAAATCAGATATTTTTTGT'],
 ['K7', '9[192]11[191]BLK', 'TTAGACGGCCAAATAAGAAACGATAGAAGGCT'],
 ['L7', '12[207]10[208]BLK', 'GTACCGCAATTCTAAGAACGCGAGTATTATTT'],
 ['M7', '9[224]11[223]BLK', 'AAAGTCACAAAATAAACAGCCAGCGTTTTA'],
 ['N7', '12[239]10[240]BLK', 'CTTATCATTCCCGACTTGCGGGAGCCTAATTT'],
 ['O7', '9[256]11[255]BLK', 'GAGAGATAGAGCGTCTTTCCAGAGGTTTTGAA'],
 ['P7', '12[271]10[272]BLK', 'TGTAGAAATCAAGATTAGTTGCTCTTACCA'],
 ['A8', '7[32]9[31]BLK', 'TTTAGGACAAATGCTTTAAACAATCAGGTC'],
 ['B8', '10[47]8[48]BLK', 'CTGTAGCTTGACTATTATAGTCAGTTCATTGA'],
 ['C8', '7[56]9[63]BLK', 'ATGCAGATACATAACGGGAATCGTCATAAATAAAGCAAAG'],
 ['D8', '10[79]8[80]BLK', 'GATGGCTTATCAAAAAGATTAAGAGCGTCC'],
 ['E8', '7[96]9[95]BLK', 'TAAGAGCAAATGTTTAGACTGGATAGGAAGCC'],
 ['F8', '10[111]8[112]BLK', 'TTGCTCCTTTCAAATATCGCGTTTGAGGGGGT'],
 ['G8', '7[120]9[127]BLK', 'CGTTTACCAGACGACAAAGAAGTTTTGCCATAATTCGA'],
 ['H8', '7[160]8[144]BLK', 'TTATTACGAAGAACTGGCATGATTGCGAGAGG'],
 ['I8', '10[143]9[159]BLK', 'CCAACAGGAGCGAACCAGACCGGAGCCTTTAC'],
 ['J8', '10[175]8[176]BLK', 'TTAACGTCTAACATAAAAACAGGTAACGGA'],
 ['K8', '7[184]9[191]BLK', 'CGTAGAAAATACATACCGAGGAAACGCAATAAGAAGCGCA'],
 ['L8', '10[207]8[208]BLK', 'ATCCCAATGAGAATTAACTGAACAGTTACCAG'],
 ['M8', '7[224]9[223]BLK', 'AACGCAAAGATAGCCGAACAAACCCTGAAC'],
 ['N8', '10[239]8[240]BLK', 'GCCAGTTAGAGGGTAATTGAGCGCTTTAAGAA'],
 ['O8', '7[248]9[255]BLK', 'GTTTATTTTGTCACAATCTTACCGAAGCCCTTTAATATCA'],
 ['P8', '10[271]8[272]BLK', 'ACGCTAACACCCACAAGAATTGAAAATAGC'],
 ['A9', '5[32]7[31]BLK', 'CATCAAGTAAAACGAACTAACGAGTTGAGA'],
 ['B9', '8[47]6[48]BLK', 'ATCCCCCTATACCACATTCAACTAGAAAAATC'],
 ['D9', '8[79]6[80]BLK', 'AATACTGCCCAAAAGGAATTACGTGGCTCA'],
 ['E9', '5[96]7[95]BLK', 'TCATTCAGATGCGATTTTAAGAACAGGCATAG'],
 ['F9', '8[111]6[112]BLK', 'AATAGTAAACACTATCATAACCCTCATTGTGA'],
 ['H9', '5[160]6[144]BLK', 'GCAAGGCCTCACCAGTAGCACCATGGGCTTGA'],
 ['I9', '8[143]7[159]BLK', 'CTTTTGCAGATAAAAACCAAAATAAAGACTCC'],
 ['J9', '8[175]6[176]BLK', 'ATACCCAACAGTATGTTAGCAAATTAGAGC'],
 ['L9', '8[207]6[208]BLK', 'AAGGAAACATAAAGGTGGCAACATTATCACCG'],
 ['M9', '5[224]7[223]BLK', 'TCAAGTTTCATTAAAGGTGAATATAAAAGA'],
 ['N9', '8[239]6[240]BLK', 'AAGTAAGCAGACACCACGGAATAATATTGACG'],
 ['P9', '8[271]6[272]BLK', 'AATAGCTATCAATAGAAAATTCAACATTCA'],
 ['A10', '3[32]5[31]BLK', 'AATACGTTTGAAAGAGGACAGACTGACCTT'],
 ['B10', '6[47]4[48]BLK', 'TACGTTAAAGTAATCTTGACAAGAACCGAACT'],
 ['D10', '6[79]4[80]BLK', 'TTATACCACCAAATCAACGTAACGAACGAG'],
 ['E10', '3[96]5[95]BLK', 'ACACTCATCCATGTTACTTAGCCGAAAGCTGC'],
 ['F10', '6[111]4[112]BLK', 'ATTACCTTTGAATAAGGCTTGCCCAAATCCGC'],
 ['H10', '3[160]4[144]BLK', 'TTGACAGGCCACCACCAGAGCCGCGATTTGTA'],
 ['I10', '6[143]5[159]BLK', 'GATGGTTTGAACGAGTAGTAAATTTACCATTA'],
 ['J10', '6[175]4[176]BLK', 'CAGCAAAAGGAAACGTCACCAATGAGCCGC'],
 ['L10', '6[207]4[208]BLK', 'TCACCGACGCACCGTAATCAGTAGCAGAACCG'],
 ['M10', '3[224]5[223]BLK', 'TTAAAGCCAGAGCCGCCACCCTCGACAGAA'],
 ['N10', '6[239]4[240]BLK', 'GAAATTATTGCCTTTAGCGTCAGACCGGAACC'],
 ['P10', '6[271]4[272]BLK', 'ACCGATTGTCGGCATTTTCGGTCATAATCA'],
 ['A11', '1[32]3[31]BLK', 'AGGCTCCAGAGGCTTTGAGGACACGGGTAA'],
 ['B11', '4[47]2[48]BLK', 'GACCAACTAATGCCACTACGAAGGGGGTAGCA'],
 ['C11', '1[64]4[64]BLK', 'TTTATCAGGACAGCATCGGAACGACACCAACCTAAAACGAGGTCAATC'],
 ['D11', '4[79]2[80]BLK', 'GCGCAGACAAGAGGCAAAAGAATCCCTCAG'],
 ['E11', '1[96]3[95]BLK', 'AAACAGCTTTTTGCGGGATCGTCAACACTAAA'],
 ['F11', '4[111]2[112]BLK', 'GACCTGCTCTTTGACCCCCAGCGAGGGAGTTA'],
 ['G11', '1[128]4[128]BLK', 'TGACAACTCGCTGAGGCTTGCATTATACCAAGCGCGATGATAAA'],
 ['H11', '1[160]2[144]BLK', 'TTAGGATTGGCTGAGACTCCTCAATAACCGAT'],
 ['I11', '4[143]3[159]BLK', 'TCATCGCCAACAAAGTACAACGGACGCCAGCA'],
 ['J11', '4[175]2[176]BLK', 'CACCAGAAAGGTTGAGGCAGGTCATGAAAG'],
 ['K11', '1[192]4[192]BLK', 'GCGGATAACCTATTATTCTGAAACAGACGATTGGCCTTGAAGAGCCAC'],
 ['L11', '4[207]2[208]BLK', 'CCACCCTCTATTCACAAACAAATACCTGCCTA'],
 ['M11', '1[224]3[223]BLK', 'GTATAGCAAACAGTTAATGCCCAATCCTCA'],
 ['N11', '4[239]2[240]BLK', 'GCCTCCCTCAGAATGGAAAGCGCAGTAACAGT'],
 ['O11', '1[256]4[256]BLK', 'CAGGAGGTGGGGTCAGTGCCTTGAGTCTCTGAATTTACCGGGAACCAG'],
 ['P11', '4[271]2[272]BLK', 'AAATCACCTTCCAGTAAGCGTCAGTAATAA'],
 ['A12', '0[47]1[31]BLK', 'AGAAAGGAACAACTAAAGGAATTCAAAAAAA'],
 ['B12', '2[47]0[48]BLK', 'ACGGCTACAAAAGGAGCCTTTAATGTGAGAAT'],
 ['C12', '0[79]1[63]BLK', 'ACAACTTTCAACAGTTTCAGCGGATGTATCGG'],
 ['D12', '2[79]0[80]BLK', 'CAGCGAAACTTGCTTTCGAGGTGTTGCTAA'],
 ['E12', '0[111]1[95]BLK', 'TAAATGAATTTTCTGTATGGGATTAATTTCTT'],
 ['F12', '2[111]0[112]BLK', 'AAGGCCGCTGATACCGATAGTTGCGACGTTAG'],
 ['G12', '0[143]1[127]BLK', 'TCTAAAGTTTTGTCGTCTTTCCAGCCGACAA'],
 ['H12', '0[175]0[144]BLK', 'TCCACAGACAGCCCTCATAGTTAGCGTAACGA'],
 ['I12', '2[143]1[159]BLK', 'ATATTCGGAACCATCGCCCACGCAGAGAAGGA'],
 ['J12', '2[175]0[176]BLK', 'TATTAAGAAGCGGGGTTTTGCTCGTAGCAT'],
 ['K12', '0[207]1[191]BLK', 'TCACCAGTACAAACTACAACGCCTAGTACCAG'],
 ['L12', '2[207]0[208]BLK', 'TTTCGGAAGTGCCGTCGAGAGGGTGAGTTTCG'],
 ['M12', '0[239]1[223]BLK', 'AGGAACCCATGTACCGTAACACTTGATATAA'],
 ['N12', '2[239]0[240]BLK', 'GCCCGTATCCGGAATAGGTGTATCAGCCCAAT'],
 ['O12', '0[271]1[255]BLK', 'CCACCCTCATTTTCAGGGATAGCAACCGTACT'],
 ['P12', '2[271]0[272]BLK', 'GTTTTAACTTAGTACCGCCACCCAGAGCCA']]

paint_sequences = [['Shortname', 'Handlesequence'],
 ['P1', 'TTATACATCTA'],
 ['P2', 'TTATCTACATA'],
 ['P3', 'TTTCTTCATTA'],
 ['P4', 'TTATGAATCTA'],
 ['P5', 'TTTCAATGTAT'],
 ['P6', 'TTTTAGGTAAA'],
 ['P7', 'TTAATTGAGTA'],
 ['P8', 'TTATGTTAATG'],
 ['P9', 'TTAATTAGGAT'],
 ['P10', 'TTATAATGGAT']]
